"use strict";

exports.__esModule = true;
exports.Model = void 0;

class Model {
  static map(entries, context) {
    return entries.map(data => new this(data, context));
  }

  static link(sources, name, callback) {
    for (const source of sources) {
      const value = callback(source);
      source.link(name, Array.isArray(value) ? value.filter(model => model != null) : value);
    }
  }

  constructor(data, context) {
    this.data = data;
    this.context = context;
    this.links = {};
  }

  link(name, value) {
    this.links[name] = Array.isArray(value) ? value.filter(value => value != null) : value;
  }

  build() {
    const data = this.fields.reduce((obj, name) => {
      obj[name] = this[name];
      return obj;
    }, {});
    const links = Object.entries(this.links).reduce((obj, [name, value]) => {
      obj[`${name}___NODE`] = Array.isArray(value) ? value.map(value => value.id) : value === null || value === void 0 ? void 0 : value.id;
      return obj;
    }, {});
    const node = {
      id: this.id,
      ...data,
      ...links,
      parent: null,
      children: [],
      internal: {
        type: this.constructor.name,
        content: JSON.stringify(data),
        contentDigest: this.context.createContentDigest(data)
      }
    };
    this.context.createNode(node);
  }

}

exports.Model = Model;
//# sourceMappingURL=Model.js.map