"use strict";

exports.__esModule = true;
exports.WordpressPost = void 0;

var _unihtml = require("unihtml");

var _content = require("../util/content");

var _Model = require("./Model");

class WordpressPost extends _Model.Model {
  constructor(...args) {
    super(...args);
    this.content = {
      tree: (0, _content.processContent)(this.data.content, this.context.transformContent),
      files: [],
      html: ''
    };
  }

  get id() {
    return this.data.id;
  }

  get fields() {
    return ['title', 'slug', 'date', 'excerpt', 'content', 'seoCanonical', 'seoTitle', 'seoDesription', 'seoKeywords', 'seoNoFollow', 'seoNoIndex'];
  }

  get title() {
    return this.data.title;
  }

  get slug() {
    return this.data.slug;
  }

  get date() {
    return this.data.date;
  }

  get excerpt() {
    return this.data.excerpt;
  }

  get seoCanonical() {
    var _this$data$seo;

    return (_this$data$seo = this.data.seo) === null || _this$data$seo === void 0 ? void 0 : _this$data$seo.canonical;
  }

  get seoTitle() {
    var _this$data$seo2;

    return (_this$data$seo2 = this.data.seo) === null || _this$data$seo2 === void 0 ? void 0 : _this$data$seo2.title;
  }

  get seoDesription() {
    var _this$data$seo3;

    return (_this$data$seo3 = this.data.seo) === null || _this$data$seo3 === void 0 ? void 0 : _this$data$seo3.metaDesc;
  }

  get seoKeywords() {
    var _this$data$seo4;

    return (_this$data$seo4 = this.data.seo) === null || _this$data$seo4 === void 0 ? void 0 : _this$data$seo4.metaKeywords;
  }

  get seoNoFollow() {
    var _this$data$seo5;

    return (_this$data$seo5 = this.data.seo) === null || _this$data$seo5 === void 0 ? void 0 : _this$data$seo5.metaRobotsNofollow;
  }

  get seoNoIndex() {
    var _this$data$seo6;

    return (_this$data$seo6 = this.data.seo) === null || _this$data$seo6 === void 0 ? void 0 : _this$data$seo6.metaRobotsNoindex;
  }

  get featuredImageId() {
    var _this$data$featuredIm, _this$data$featuredIm2, _this$data$featuredIm3, _this$data$featuredIm4;

    return (_this$data$featuredIm = this.data.featuredImage) !== null && _this$data$featuredIm !== void 0 && (_this$data$featuredIm2 = _this$data$featuredIm.node) !== null && _this$data$featuredIm2 !== void 0 && _this$data$featuredIm2.id ? String((_this$data$featuredIm3 = this.data.featuredImage) === null || _this$data$featuredIm3 === void 0 ? void 0 : (_this$data$featuredIm4 = _this$data$featuredIm3.node) === null || _this$data$featuredIm4 === void 0 ? void 0 : _this$data$featuredIm4.id) : undefined;
  }

  get authorId() {
    return this.data.authorId;
  }

  get categoryIds() {
    var _this$data$categories;

    return (_this$data$categories = this.data.categories) !== null && _this$data$categories !== void 0 && _this$data$categories.nodes ? this.data.categories.nodes.map(({
      databaseId
    }) => databaseId) : [];
  }

  get seoImageId() {
    var _this$data$seo7, _this$data$seo7$openg;

    return (_this$data$seo7 = this.data.seo) === null || _this$data$seo7 === void 0 ? void 0 : (_this$data$seo7$openg = _this$data$seo7.opengraphImage) === null || _this$data$seo7$openg === void 0 ? void 0 : _this$data$seo7$openg.id;
  }

  extractImageUrls(fileNodes) {
    const postFileNodes = [];
    (0, _unihtml.transform)(this.content.tree, ({
      custom
    }) => {
      custom(node => node.type === 'element' && node.tagName === 'img', (node, index, parent) => {
        if (index === null || parent === null) {
          return;
        }

        const fileNode = fileNodes.find(({
          url
        }) => url === node.properties.src);

        if (!fileNode) {
          return;
        }

        node.properties.src = `fileNode://${fileNode.id}`;
        postFileNodes.push(fileNode);
      });
    });
    this.content.files = postFileNodes.map(({
      id
    }) => id);
    this.content.html = (0, _unihtml.stringify)(this.content.tree);
    return postFileNodes;
  }

}

exports.WordpressPost = WordpressPost;
//# sourceMappingURL=WordpressPost.js.map