"use strict";

exports.__esModule = true;
exports.FilterSet = void 0;

class FilterSet {
  static process(sourceRecords, callback) {
    const filterSet = new FilterSet(sourceRecords);
    callback({
      exclude: matcher => {
        filterSet.exclude(matcher);
      },
      include: matcher => {
        filterSet.include(matcher);
      }
    });
    return filterSet.records;
  }

  static include(sourceRecords, matcher) {
    return new FilterSet(sourceRecords).include(matcher).records;
  }

  static exclude(sourceRecords, matcher) {
    return new FilterSet(sourceRecords).exclude(matcher).records;
  }

  constructor(sourceRecords) {
    this.sourceRecords = sourceRecords;
    this.includeRecords = new Set();
    this.excludeRecords = new Set();
  }

  include(matcher) {
    for (const record of this.sourceRecords) {
      if (matcher(record)) {
        this.includeRecords.add(record);
      }
    }

    return this;
  }

  exclude(matcher) {
    for (const record of this.sourceRecords) {
      if (matcher(record)) {
        this.excludeRecords.add(record);
      }
    }

    return this;
  }

  get records() {
    return this.sourceRecords.filter(record => {
      return this.includeRecords.has(record) && !this.excludeRecords.has(record);
    });
  }

}

exports.FilterSet = FilterSet;
//# sourceMappingURL=FilterSet.js.map