"use strict";

exports.__esModule = true;
exports.MediaItemImporter = void 0;

var _asyncSema = require("async-sema");

var _gatsbySourceFilesystem = require("gatsby-source-filesystem");

class MediaItemImporter {
  constructor({
    batchSize,
    args,
    cache
  }) {
    this.batchSize = void 0;
    this.args = void 0;
    this.cache = void 0;
    this.batchSize = batchSize !== null && batchSize !== void 0 ? batchSize : 10;
    this.args = args;
    this.cache = cache;
  }

  async process(mediaItems) {
    var _await$this$cache$get;

    const importData = (_await$this$cache$get = await this.cache.get('mediaItems:imported')) !== null && _await$this$cache$get !== void 0 ? _await$this$cache$get : [];
    const syncProgress = this.args.reporter.createProgress('wordpress-graphql: import media items', mediaItems.length, 0);
    syncProgress.start();
    const sema = new _asyncSema.Sema(this.batchSize, {
      capacity: mediaItems.length
    });
    const newImportData = await Promise.all(mediaItems.map(async mediaItem => {
      var _importData$find;

      await sema.acquire();
      const data = (_importData$find = importData.find(({
        mediaItemId
      }) => mediaItemId === mediaItem.id)) !== null && _importData$find !== void 0 ? _importData$find : await this.importMediaItem(mediaItem);

      if (data) {
        mediaItem.sourceNodeId = data.fileNode.id;
      }

      syncProgress.tick();
      sema.release();
      return data;
    }));
    const finalImportData = newImportData.filter(Boolean);
    await this.cache.set('mediaItems:imported', finalImportData);
    syncProgress.done();
    return finalImportData.map(({
      fileNode
    }) => fileNode);
  }

  async importMediaItem(mediaItem) {
    var _mediaItem$altText;

    const {
      cache,
      store,
      reporter,
      createNodeId,
      actions: {
        createNode
      }
    } = this.args;

    if (!mediaItem.sourceUrl) {
      return null;
    }

    const name = (_mediaItem$altText = mediaItem.altText) !== null && _mediaItem$altText !== void 0 ? _mediaItem$altText : mediaItem.name;
    const fileNode = await (0, _gatsbySourceFilesystem.createRemoteFileNode)({
      url: encodeURI(mediaItem.sourceUrl),
      name,
      cache,
      store,
      reporter,
      createNode,
      createNodeId,
      parentNodeId: mediaItem.id
    });
    return {
      mediaItemId: mediaItem.id,
      fileNode
    };
  }

}

exports.MediaItemImporter = MediaItemImporter;
//# sourceMappingURL=MediaItemImporter.js.map