"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.WordpressClient = void 0;

var _core = require("@apollo/client/core");

var _crossFetch = _interopRequireDefault(require("cross-fetch"));

var _graphql = require("../graphql");

class WordpressClient {
  constructor(options) {
    var _options$perPage;

    this.perPage = void 0;
    this.reporter = void 0;
    this.cache = void 0;
    this.client = void 0;
    this.perPage = (_options$perPage = options.perPage) !== null && _options$perPage !== void 0 ? _options$perPage : 100;
    this.reporter = options.args.reporter;
    this.cache = options.cache;
    const link = new _core.HttpLink({
      uri: options.host,
      headers: {
        'Authorization': options.authorization
      },
      fetch: _crossFetch.default
    });
    const cache = new _core.InMemoryCache();
    this.client = new _core.ApolloClient({
      link,
      cache
    });
  }

  async getPosts() {
    return this.fetchLatest('posts', async pageInfo => {
      var _data$posts$nodes;

      const {
        data
      } = await this.client.query({
        query: _graphql.GetPostsDocument,
        variables: {
          before: pageInfo.startCursor,
          last: this.perPage
        }
      });

      if (!data || !data.posts.pageInfo) {
        return {
          pageInfo: {
            hasPreviousPage: false
          },
          records: []
        };
      }

      return {
        pageInfo: data.posts.pageInfo,
        records: (_data$posts$nodes = data.posts.nodes) !== null && _data$posts$nodes !== void 0 ? _data$posts$nodes : []
      };
    });
  }

  async getPages() {
    return this.fetchLatest('pages', async pageInfo => {
      var _data$pages$nodes;

      const {
        data
      } = await this.client.query({
        query: _graphql.GetPagesDocument,
        variables: {
          before: pageInfo.startCursor,
          last: this.perPage
        }
      });

      if (!data || !data.pages.pageInfo) {
        return {
          pageInfo: {
            hasPreviousPage: false
          },
          records: []
        };
      }

      return {
        pageInfo: data.pages.pageInfo,
        records: (_data$pages$nodes = data.pages.nodes) !== null && _data$pages$nodes !== void 0 ? _data$pages$nodes : []
      };
    });
  }

  async getMediaItems() {
    return this.fetchLatest('mediaItems', async pageInfo => {
      var _data$mediaItems$node;

      const {
        data
      } = await this.client.query({
        query: _graphql.GetMediaItemsDocument,
        variables: {
          before: pageInfo.startCursor,
          last: this.perPage
        }
      });

      if (!data || !data.mediaItems.pageInfo) {
        return {
          pageInfo: {
            hasPreviousPage: false
          },
          records: []
        };
      }

      return {
        pageInfo: data.mediaItems.pageInfo,
        records: (_data$mediaItems$node = data.mediaItems.nodes) !== null && _data$mediaItems$node !== void 0 ? _data$mediaItems$node : []
      };
    });
  }

  async fetchLatest(cacheKey, fetchMore) {
    var _await$this$cache$get;

    const records = (_await$this$cache$get = await this.cache.get(cacheKey)) !== null && _await$this$cache$get !== void 0 ? _await$this$cache$get : [];
    const syncProgress = this.reporter.createProgress(`wordpress-graphql: sync ${cacheKey}`, records.length + this.perPage, records.length);
    syncProgress.start();
    const pageInfo = {
      startCursor: await this.cache.get(`${cacheKey}:startCursor`),
      hasPreviousPage: true
    };

    while (pageInfo.hasPreviousPage) {
      const result = await fetchMore(pageInfo);
      records.push(...result.records);
      syncProgress.setStatus(`retrieved ${records.length} ${cacheKey}`);
      syncProgress.total = records.length;
      syncProgress.tick(result.records.length);

      if (result.pageInfo.startCursor) {
        pageInfo.startCursor = result.pageInfo.startCursor;
      }

      pageInfo.hasPreviousPage = result.pageInfo.hasPreviousPage;

      if (pageInfo.hasPreviousPage) {
        syncProgress.total = records.length + 10;
      }
    }

    await this.cache.set(cacheKey, records);
    await this.cache.set(`${cacheKey}:startCursor`, pageInfo.startCursor);
    syncProgress.total = records.length;
    syncProgress.tick(0);
    syncProgress.done();
    return records;
  }

}

exports.WordpressClient = WordpressClient;
//# sourceMappingURL=WordpressClient.js.map