"use strict";

exports.__esModule = true;
exports.sourceNodes = sourceNodes;
exports.CacheAdapterMap = void 0;

var _Cache = require("./lib/Cache");

var _CacheAdapterGatsby = require("./lib/CacheAdapter/CacheAdapterGatsby");

var _CacheAdapterPersist = require("./lib/CacheAdapter/CacheAdapterPersist");

var _FilterSet = require("./lib/FilterSet");

var _MediaItemImporter = require("./lib/MediaItemImporter");

var _WordpressClient = require("./lib/WordpressClient");

var _WordpressMediaItem = require("./Models/WordpressMediaItem");

var _WordpressPage = require("./Models/WordpressPage");

var _WordpressPost = require("./Models/WordpressPost");

var _content = require("./util/content");

const CacheAdapterMap = {
  'gatsby': _CacheAdapterGatsby.CacheAdapterGatsby,
  'persist': _CacheAdapterPersist.CacheAdapterPersist
};
exports.CacheAdapterMap = CacheAdapterMap;

async function sourceNodes(args, {
  host,
  authorization,
  cacheAdapter,
  perPage,
  batchSize,
  transformContent
}) {
  const CacheAdapter = CacheAdapterMap[cacheAdapter];
  const adapter = new CacheAdapter(args);
  const cache = new _Cache.Cache(adapter);
  const mediaItemImporter = new _MediaItemImporter.MediaItemImporter({
    args,
    cache,
    batchSize
  });
  const client = new _WordpressClient.WordpressClient({
    host,
    authorization,
    cache,
    args,
    perPage
  });
  const context = {
    createNodeId: args.createNodeId,
    createNode: args.actions.createNode,
    createContentDigest: args.createContentDigest,
    transformContent
  }; // Retrieve Data

  const posts = _WordpressPost.WordpressPost.map(await client.getPosts(), context);

  const pages = _WordpressPage.WordpressPage.map(await client.getPages(), context);

  const allMediaItems = _WordpressMediaItem.WordpressMediaItem.map(await client.getMediaItems(), context); // Filter Media Items


  const allRecords = [...posts, ...pages];
  const sourceUrls = (0, _content.findImageUrls)(allRecords);

  const mediaItems = _FilterSet.FilterSet.include(allMediaItems, ({
    sourceUrl,
    id
  }) => {
    return sourceUrls.has(sourceUrl) || allRecords.findIndex(({
      featuredImageId
    }) => featuredImageId === id) !== -1;
  }); // Import Media Items


  const fileNodes = await mediaItemImporter.process(mediaItems); // Link Content Files

  for (const post of posts) {
    post.extractImageUrls(fileNodes);
  }

  for (const page of pages) {
    page.extractImageUrls(fileNodes);
  } // Link Featured Image


  _WordpressPost.WordpressPost.link(posts, 'featuredImage', ({
    featuredImageId
  }) => mediaItems.find(({
    id
  }) => featuredImageId === id));

  _WordpressPage.WordpressPage.link(pages, 'featuredImage', ({
    featuredImageId
  }) => mediaItems.find(({
    id
  }) => featuredImageId === id)); // Build Content Nodes


  for (const model of [...mediaItems, ...posts, ...pages]) {
    model.build();
  }
}
//# sourceMappingURL=sourceNodes.js.map